# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
# Only generate repolib on RHEL-6
%if "%{?rhel}" == "6"
%define _jarsign_opts --unsign=%{_javadir}
%bcond_without repolib
%else
%bcond_with repolib
%endif
%bcond_without mead

%define repodir %{_javadir}/repository.jboss.com/jboss/common-core/%{namedversion}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define section free
%define namedversion %{version}.GA

Name:           jboss-common-core
Version:        2.2.17
Release:        1%{?dist}
Epoch:          0
Summary:        JBoss Common core utility classes
License:        LGPLv2+
URL:            http://www.jboss.org/
Group:          Development/Libraries/Java
# svn export http://anonsvn.jboss.org/repos/common/common-core/tags/2.2.17.GA/ jboss-common-core-2.2.17
# Exported revision 3877.
# tar cjf jboss-common-core-2.2.17.tar.bz2 jboss-common-core-2.2.17
%if %without mead
Source0:        %{name}-%{version}.tar.bz2
%endif
Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml
Source3:        %{name}-component-info.xml
Patch0:		%{name}-pom_xml.patch

Obsoletes:      jboss-common < %{epoch}:%{version}-%{release}

Requires(post): jpackage-utils >= 0:1.7.3
Requires(postun): jpackage-utils >= 0:1.7.3
Requires:       java >= 0:1.5.0
Requires:       jboss-common-logging-spi

%if %with mead
BuildRequires:  %{name}-mead = %{namedversion}
%else
BuildRequires:  java-devel >= 0:1.5.0
BuildRequires:  jpackage-utils >= 0:1.7.3
BuildRequires:  jakarta-commons-httpclient
BuildRequires:  jakarta-slide-webdavclient
BuildRequires:  jboss-common-logging-spi
BuildRequires:  jboss-deploy-maven-plugin
BuildRequires:  jboss-parent >= 0:4.0
BuildRequires:  junit
BuildRequires:  junit4
BuildRequires:  maven-scm
BuildRequires:  maven2 >= 0:2.0.7
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-project-info-reports
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-site
BuildRequires:  maven2-plugin-source
BuildRequires:  maven2-default-skin
BuildRequires:  maven-release
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit4
BuildRequires:  maven-surefire-report-maven-plugin
BuildRequires:  mojo-maven2-plugin-taglist

# FIXME OPENJDK: Temporary workaround
BuildRequires: liberation-fonts
%endif

BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
JBoss Common core utility classes.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

# FIXME If manual is desired for JBoss Common Core
# some manual JAR must be creaed and and installed by the maven build
%if %without mead
%package manual
Summary:        Documents for %{name}
Group:          Development/Documentation

%description manual
%{summary}.
%endif

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%if %without mead
%setup -q
%patch0 -b .sav0
cp -p %{SOURCE1} settings.xml
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/m2_repo/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/m2_repo/repository</url>|g" settings.xml

mkdir -p external_repo
ln -s %{_javadir} external_repo/JPP

find . -name "*.jar" -exec rm -f {} \;
%endif

%build
%if %without mead
export MAVEN_REPO_LOCAL=$(pwd)/m2_repo/repository
export M2_SETTINGS=$(pwd)/settings.xml
%{_bindir}/mvn-jpp \
        -e \
        -s $M2_SETTINGS \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        install javadoc:javadoc site
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %without mead
# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -p -m 644 target/%{name}-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} ${jar/-%{version}/}; done)

# pom
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -p -m 644 pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap org.jboss %{name} %{namedversion} JPP %{name}

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

## manual
install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -pr target/site/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
rm -rf $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/apidocs
%else
# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -p -m 644 %{_javadir}/jbossas-fordev/%{name}-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} ${jar/-%{version}/}; done)

# pom
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -p -m 644 %{_javadir}/jbossas-fordev/%{name}-%{namedversion}.pom $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap org.jboss %{name} %{namedversion} JPP %{name}

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
pushd $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
unzip %{_javadir}/jbossas-fordev/%{name}-%{namedversion}-javadoc.jar
popd
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}
%endif

%if %with repolib
%{__install} -d -m 755 %{buildroot}%{repodir}
%{__install} -d -m 755 %{buildroot}%{repodirlib}
%{__install} -p -m 644 %{SOURCE3} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@VERSION@/%{namedversion}-brew/g" %{buildroot}%{repodir}/component-info.xml
%{__install} -d -m 755 %{buildroot}%{repodirsrc}
%if %without mead
%{__install} -p -m 644 %{SOURCE0} %{buildroot}%{repodirsrc}
%endif
%{__install} -p -m 644 %{SOURCE1} %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{SOURCE2} %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{PATCH0} %{buildroot}%{repodirsrc}
%{__cp} -p %{buildroot}%{_javadir}/%{name}-%{version}.jar %{buildroot}%{repodirlib}/jboss-common-core.jar
%{__cp} -p %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom %{buildroot}%{repodirlib}/jboss-common-core.pom
%if %without mead
%{__cp} -p target/%{name}-%{namedversion}-sources.jar %{buildroot}%{repodirlib}/jboss-common-core-sources.jar
%else
%{__cp} -p %{_javadir}/jbossas-fordev/%{name}-%{namedversion}-sources.jar %{buildroot}%{repodirlib}/jboss-common-core-sources.jar
%endif
%{__install} -p -m 755 %{SOURCE4} %{buildroot}%{repodir}/upload.sh
%if %without mead
pushd %{buildroot}%{repodir}
./upload.sh %{buildroot}/usr/share/java/repository.jboss.com/maven2-brew/
popd
%endif
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%{_javadir}*/%{name}-%{version}.jar
%{_javadir}*/%{name}.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%if %without mead
%files manual
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}
%endif

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}*
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Fri Feb 11 2011 Fernando Nasser <fnasser@redhat.com> 0:2.2.17-1
- Upgrade to 2.2.17.GA for EAP 5.1.1

* Wed Jan 19 2011 Fernando Nasser <fnasser@redhat.com> 0:2.2.16-6
- Use MEAD-built binaries

* Fri Jul 09 2010 Martha Benitez <mbenitez@redhat.com> 0:2.2.16-3
- Add Obsoletes jboss-common

* Tue Jun 22 2010 David Walluck <dwalluck@redhat.com> 0:2.2.16-2.2.2
- rebuild

* Tue Apr 6 2010 Yiqiao Wang <yiwang@redhat.com> 0:2.2.16-2.1
- Rebuild

* Fri Nov 20 2009 Martha Benitez <mbenitez@redhat.com> 0:2.2.16-2
- Add pom.xml to repolib
- Add patch for pom.xml dependency versions

* Wed Oct 07 2009 Permaine Cheung <pcheung@redhat.com> 0:2.2.16-1
- Upgrade to 2.2.16
- Fix component-info.xml
- jboss-common-core-build.patch no longer needed

* Tue Sep 01 2009 Fernando Nasser <fnasser@redhat.com> 0:2.2.15-2
- Update the component-info
- Generate and install source.jar in repolib

* Tue Sep 01 2009 Fernando Nasser <fnasser@redhat.com> 0:2.2.15-1
- Upgrade to 2.2.15

* Thu Jun 11 2009 Martha Benitez <mbenitez@redhat.com> 0:2.2.14-2.1
- Change jpackage-utils >= 0:1.7.5 to jpackage-utils >= 0:1.7.3
 
* Tue May 26 2009 David Walluck <dwalluck@redhat.com> 0:2.2.14-2
- enable site

* Thu May 21 2009 David Walluck <dwalluck@redhat.com> 0:2.2.14-1
- 2.2.14

* Wed May 20 2009 David Walluck <dwalluck@redhat.com> 0:2.2.13-1
- 2.2.13.GA

* Mon Apr 13 2009 David Walluck <dwalluck@redhat.com> 0:2.2.11-1
- 2.2.11.GA

* Tue Feb 10 2009 David Walluck <dwalluck@redhat.com> 0:2.2.10-4
- small cleanup

* Tue Feb 10 2009 David Walluck <dwalluck@redhat.com> 0:2.2.10-3
- add Requires for jpackage-utils

* Mon Feb 09 2009 David Walluck <dwalluck@redhat.com> 0:2.2.10-2
- fix repolib location

* Mon Feb 09 2009 David Walluck <dwalluck@redhat.com> 0:2.2.10-1
- 2.2.10.GA
- add repolib

* Fri Feb 06 2009 Ralph Apel <r.apel@r-apel.de> 0:2.2.8-1.jpp5
- First release
